@@ -1,23 +1,29 @@
-import timeago
 import datetime
 from datetime import timezone
+from typing import Dict, List
 
-from doing.utils import run_command, get_repo_name, replace_user_aliases, validate_work_item_type
-from rich.table import Table
+import timeago
+from rich.console import Console
 from rich.live import Live
 from rich.progress import track
-from rich.console import Console
+from rich.table import Table
 
-from typing import List, Dict
+from doing.utils import get_config, get_repo_name, replace_user_aliases, run_command, validate_work_item_type
 
 console = Console()
 
 
 def work_item_query(
-    assignee: str, author: str, label: str, state: str, area: str, iteration: str, type: str, story_points: str
+    assignee: str,
+    author: str,
+    label: str,
+    state: str,
+    area: str,
+    iteration: str,
+    work_item_type: str,
+    story_points: str,
 ):
-    """
-    Build query in wiql.
+    """Build query in wiql.
 
     # More on 'work item query language' syntax:
     # https://docs.microsoft.com/en-us/azure/devops/boards/queries/wiql-syntax?view=azure-devops
@@ -28,26 +34,48 @@ def work_item_query(
 
     # Get all workitems
     query = "SELECT [System.Id],[System.Title],[System.AssignedTo],"
-    query += "[System.WorkItemType],[System.State],[System.CreatedDate]"
+    query += "[System.WorkItemType],[System.State],[System.CreatedDate], [System.State] "
     query += f"FROM WorkItems WHERE [System.AreaPath] = '{area}' "
     # Filter on iteration. Note we use UNDER so that user can choose to provide teams path for all sprints.
     query += f"AND [System.IterationPath] UNDER '{iteration}' "
+
     if assignee:
         query += f"AND [System.AssignedTo] = '{assignee}' "
+
     if author:
         query += f"AND [System.CreatedBy] = '{author}' "
+
     if label:
         for lab in label.split(","):
             query += f"AND [System.Tags] Contains '{lab.strip()}' "
-    if state == "open":
-        query += "AND [System.State] NOT IN ('Resolved','Closed','Done','Removed') "
-    if state == "closed":
-        query += "AND [System.State] IN ('Resolved','Closed','Done') "
-    if state == "all":
-        query += "AND [System.State] <> 'Removed' "
-    if type:
-        validate_work_item_type(type)
-        query += f"AND [System.WorkItemType] = '{type}' "
+
+    if state:
+        custom_states = get_config("custom_states", {})
+        if state in custom_states.keys():
+            if type(custom_states[state]) is not list:
+                custom_states[state] = [custom_states[state]]
+            state_list = ",".join([f"'{x}'" for x in custom_states[state]])
+            query += f"AND [System.State] IN ({state_list}) "
+        elif state == "open":
+            query += "AND [System.State] NOT IN ('Resolved','Closed','Done','Removed') "
+        elif state == "closed":
+            query += "AND [System.State] IN ('Resolved','Closed','Done') "
+        elif state == "all":
+            query += "AND [System.State] <> 'Removed' "
+        elif state.startswith("'") and state.endswith("'"):
+            query += f"AND [System.State] = {state} "
+        else:
+            raise ValueError(
+                f"Invalid state: '{state}'. State should be:\n"
+                "- one of the doing-cli default states: 'open', 'closed', 'all'\n"
+                "- a custom state defined under 'custom_states' in the .doing-cli.config.yml file\n"
+                "- a state available in this team, between quotes, e.g. \"'Active'\""
+            )
+
+    if work_item_type:
+        validate_work_item_type(work_item_type)
+        query += f"AND [System.WorkItemType] = '{work_item_type}' "
+
     if story_points:
         if story_points == "unassigned":
             query += "AND [Microsoft.VSTS.Scheduling.StoryPoints] = '' "
@@ -68,6 +96,7 @@ def work_item_query(
 
     # Ordering of results
     query += "ORDER BY [System.CreatedDate] asc"
+
     return query
 
 
@@ -81,18 +110,17 @@ def cmd_list(
     iteration: str,
     organization: str,
     project: str,
-    type: str,
+    work_item_type: str,
+    show_state: bool,
     story_points: str = "",
     output_format: str = "table",
 ) -> None:
-    """
-    Run `doing list` command.
-    """
+    """Run `doing list` command."""
     # Get config settings
     assignee = replace_user_aliases(assignee)
     author = replace_user_aliases(author)
 
-    query = work_item_query(assignee, author, label, state, area, iteration, type, story_points)
+    query = work_item_query(assignee, author, label, state, area, iteration, work_item_type, story_points)
     work_items = run_command(f'az boards query --wiql "{query}" --org "{organization}" -p "{project}"')
 
     if len(work_items) == 0:
@@ -115,7 +143,17 @@ def cmd_list(
     query += '--status active --query "[].pullRequestId"'
     active_pullrequest_ids = run_command(query)
 
-    with Live(build_table(work_items, workitem_prs, iteration, False), refresh_per_second=4, console=console) as live:
+    with Live(
+        build_table(
+            work_items=work_items,
+            workitem_prs=workitem_prs,
+            iteration=iteration,
+            last_build=False,
+            show_state=show_state,
+        ),
+        refresh_per_second=4,
+        console=console,
+    ) as live:
 
         # For each PR, get linked work items. Note that "az repos pr list --include-links" does not work :(
         # Posted issue on bug here: https://github.com/Azure/azure-cli-extensions/issues/2946
@@ -129,21 +167,39 @@ def cmd_list(
                 else:
                     workitem_prs[work_item] = [str(pr_id)]
 
-            live.update(build_table(work_items, workitem_prs, iteration, False))
+            live.update(
+                build_table(
+                    work_items=work_items,
+                    workitem_prs=workitem_prs,
+                    iteration=iteration,
+                    last_build=False,
+                    show_state=show_state,
+                )
+            )
 
-        live.update(build_table(work_items, workitem_prs, iteration, last_build=True))
+        live.update(
+            build_table(
+                work_items=work_items,
+                workitem_prs=workitem_prs,
+                iteration=iteration,
+                last_build=False,
+                show_state=show_state,
+            )
+        )
 
 
-def build_table(work_items: List, workitem_prs: Dict, iteration: str, last_build: bool = False) -> Table:
-    """
-    Build rich table with open issues.
-    """
+def build_table(
+    work_items: List, workitem_prs: Dict, iteration: str, show_state: bool, last_build: bool = False
+) -> Table:
+    """Build rich table with open issues."""
     # Create our table
     table = Table(title=f"Work-items in current iteration {iteration}")
     table.add_column("ID", justify="right", style="cyan", no_wrap=True)
     table.add_column("Title", justify="left", style="cyan", no_wrap=False)
     table.add_column("Assignee", justify="left", style="cyan", no_wrap=False)
     table.add_column("Type", justify="left", style="cyan", no_wrap=True)
+    if show_state:
+        table.add_column("State", justify="right", style="cyan", no_wrap=True)
     table.add_column("Created", justify="right", style="cyan", no_wrap=True)
     table.add_column("PRs", justify="right", style="cyan", no_wrap=True)
 
@@ -157,6 +213,7 @@ def build_table(work_items: List, workitem_prs: Dict, iteration: str, last_build
         item_title = fields.get("System.Title")
         item_createdby = fields.get("System.AssignedTo", {}).get("displayName", "")
         item_type = fields.get("System.WorkItemType")
+        item_state = fields.get("System.State")
 
         # For example:
         # '2020-11-17T13:33:32.463Z'
@@ -179,6 +236,9 @@ def build_table(work_items: List, workitem_prs: Dict, iteration: str, last_build
             item_linked_prs = "[bright_black]loading..[bright_black]"
 
         # TODO: If current git branch equal to branch ID name, different color.
-        table.add_row(str(item_id), item_title, item_createdby, item_type, item_datetime, item_linked_prs)
+        row = [str(item_id), item_title, item_createdby, item_type, item_datetime, item_linked_prs]
+        if show_state:
+            row.insert(4, item_state)
+        table.add_row(*row)
 
     return table
