@@ -1,11 +1,12 @@
 import click
 from rich.console import Console
-from doing.pr.list_pr import cmd_list_pr
-from doing.utils import get_config, run_command, get_repo_name, shell_output
+
+from doing.open import commands as open_group
 from doing.options import get_common_options
 from doing.pr.create_pr import cmd_create_pr
+from doing.pr.list_pr import cmd_list_pr
 from doing.pr.open_pr import cmd_open_pr
-from doing.open import commands as open_group
+from doing.utils import get_config, get_repo_name, run_command, shell_output
 
 console = Console()
 
@@ -105,6 +106,15 @@ def close(pr_id):
     help="Open newly created issue in the web browser.",
     show_envvar=True,
 )
+@click.option(
+    "--default-branch",
+    "-b",
+    required=False,
+    default="",
+    type=str,
+    help="The name of the branch to branch from and to. It overrides the repository's default branch.",
+    show_envvar=True,
+)
 def create(
     work_item_id: str,
     draft: bool,
@@ -113,6 +123,7 @@ def create(
     reviewers: str,
     checkout: bool,
     delete_source_branch: bool,
+    default_branch,
     web: bool,
 ) -> None:
     """
@@ -128,6 +139,7 @@ def create(
         reviewers,
         checkout,
         delete_source_branch,
+        default_branch,
         **get_common_options(),
     )
     if web:
